#ifndef DLTFILEUTILS_H
#define DLTFILEUTILS_H

#include <QDir>
#include "settingsdialog.h"

class DltFileUtils : QObject
{
    Q_OBJECT
public:
    DltFileUtils();
    static QString createTempFile(QDir path,  bool silentmode);
    static QDir getTempPath(SettingsDialog *settings, bool silentmode);
};

#endif // DLTFILEUTILS_H
